## Calculate some simple statistics.
## Plot the total produced ore, total produced gold, and grade as 
## as a function of first year of production (Figure 2) and as a function of 
## production order (Figure 3).
##

library(ggplot2)
library(dplyr)

load("Data\\mineData.dat")

# -----------------

cat(sprintf("Number of mines that started production between 1910 and 1942 = %d\n",
            sum(1910 <= mineData$StartingYear & mineData$StartingYear <= 1942)))

cat(sprintf("Number of mines that started production between 1943 and 1981 = %d\n",
            sum(1943 <= mineData$StartingYear & mineData$StartingYear <= 1981)))

cat(sprintf("Number of mines that started production between 1982 and 2018 = %d\n",
            sum(1982 <= mineData$StartingYear & mineData$StartingYear <= 2018)))

# -----------------

cat(sprintf("Number of current producers = %d\n",
            sum(mineData$Classification == "Current Producer")))

cat(sprintf("Number of mines that started production between 1910 and 1942 and are current producers = %d\n",
            sum(1910 <= mineData$StartingYear & mineData$StartingYear <= 1942 &
                  mineData$Classification == "Current Producer")))


cat(sprintf("Number of mines that started production between 1982 and 2018 and are current producers = %d\n",
            sum(1982 <= mineData$StartingYear & mineData$StartingYear <= 2018 &
                  mineData$Classification == "Current Producer")))

####-------------------------------------------------------------------------

cat(sprintf("Number of mines in first interval with ore production greater than 2e7 metric tons = %d\n",
            sum(mineData$StartingYear <= 1942 & 2e7 < mineData$OreTons)))

cat(sprintf("Number of mines in third interval with ore production greater than 2e7 metric tons = %d\n",
            sum(1982 <= mineData$StartingYear & 2e7 < mineData$OreTons)))

cat(sprintf("Number of mines in first interval with gold production greater than 1e8 grams = %d\n",
            sum(mineData$StartingYear <= 1942 & 1e8 < mineData$GoldGrams)))

cat(sprintf("Number of mines in third interval with gold production greater than 1e8 grams = %d\n",
            sum(1982 <= mineData$StartingYear & 1e8 < mineData$GoldGrams)))

cat(sprintf("Number of mines in first interval with gold grade greater than 8 grams per metric ton = %d\n",
            sum(mineData$StartingYear <= 1942 & 8 < mineData$Grade)))

cat(sprintf("Number of mines in third interval with gold greater than 8 grams per metric ton = %d\n",
            sum(1982 <= mineData$StartingYear & 8 < mineData$Grade)))

####-------------------------------------------------------------------------
# Figure 2

sym_colors <- c("blue", "red")

p1 <- ggplot(mineData) +
  geom_point(aes(x = StartingYear, y = OreTons, color = Classification)) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "First year of production",
                     breaks = seq(from = 1910, to = 2010, by = 10)) +
  scale_y_continuous(name = "Total produced ore,\nin metric tons")  +
  theme_bw() +
  ggtitle("A.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

p2 <- ggplot(mineData) +
  geom_point(aes(x = StartingYear, y = GoldGrams, color = Classification)) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "First year of production",
                     breaks = seq(from = 1910, to = 2010, by = 10)) +
  scale_y_continuous(name = "Total produced gold,\nin grams")  +
  theme_bw() +
  ggtitle("B.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

p3 <- ggplot(mineData) +
  geom_point(aes(x = StartingYear, y = Grade, color = Classification)) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "First year of production",
                     breaks = seq(from = 1910, to = 2010, by = 10)) +
  scale_y_continuous(name = "\nGold grade,\nin grams per kilogram")  +
  theme_bw() +
  ggtitle("C.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(3,1)))
plot(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
plot(p2, vp=grid::viewport(layout.pos.row=2, layout.pos.col=1))
plot(p3, vp=grid::viewport(layout.pos.row=3, layout.pos.col=1))

# -----------------
# Figure 3

q1 <- ggplot() +
  geom_point(aes(x = productionOrder, y = OreTons, color = Classification),
             data = mineData, shape = 16) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = "Total produced ore,\nin metric tons", trans = "log10")  +
  theme_bw() +
  ggtitle("A.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

q2 <- ggplot() +
  geom_point(aes(x = productionOrder, y = GoldGrams, color = Classification), 
             data = mineData, shape = 16) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = "Total produced gold,\nin grams", trans = "log10")  +
  theme_bw() +
  ggtitle("B.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

q3 <- ggplot(mineData) +
  geom_point(aes(x = productionOrder, y = Grade, color = Classification), 
             data = mineData, shape = 16) +
  scale_color_manual(values = sym_colors) +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = "\nGold grade,\nin grams per kilogram")  +
  theme_bw() +
  ggtitle("C.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")


grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(3,1)))
plot(q1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
plot(q2, vp=grid::viewport(layout.pos.row=2, layout.pos.col=1))
plot(q3, vp=grid::viewport(layout.pos.row=3, layout.pos.col=1))

