##
## Model, using linear regression, the total produced gold as a function of the 
## production order. Plot the results (Figure 4).
##

library(ggplot2)
library(dplyr)

load("Data\\mineData.dat")

fit <- lm(log10(GoldGrams) ~ productionOrder, data = mineData)
summary(fit)

tmp <- summary(fit)$coefficients
intercept <- tmp[1,1]
slope <- tmp[2,1]
std_err <- tmp[2,2]

df1 <- data_frame(x = sort(mineData$productionOrder),
                  y = intercept + slope * x)

# DeGroot and Schervish, p. 625, eqn 10.3.20
n <- nrow(mineData)
S2 <- sum(fit$residuals^2)
sigma_prime <- sqrt(S2 / (n - 2))
sx <- sqrt(sum((mineData$productionOrder - mean(mineData$productionOrder))^2))
df2 <- data_frame(x = seq(from = slope - 3 * std_err, to = slope + 3 * std_err, length.out = 1000),
                  z = (x - slope) / (sigma_prime / sx),
                  y = sx / sigma_prime * dt(z, n-2))

# Figure 4
p1 <- ggplot() +
  geom_line(aes(x = x, y = y), data = df1, color = "blue", size = 1) +
  geom_point(aes(x = productionOrder, y = log10(GoldGrams)), 
             data = mineData, shape = 16, color = "black") +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = quote(log[10]("Total produced gold")))  +
  theme_bw() +
  ggtitle("A.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

  
p2 <- ggplot(df2) +
  geom_line(aes(x = x, y = y)) +
  geom_vline(xintercept = 0.0, color = "gray75") +
  geom_rug(aes(x = slope), data = data_frame(slope = slope), color = "blue", size = 2) +
  scale_x_continuous(name = "Slope") +
  scale_y_continuous(name = "Density")  +
  theme_bw() +
  ggtitle("B.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(1,3)))
plot(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1:2))
plot(p2, vp=grid::viewport(layout.pos.row=1, layout.pos.col=3))


