##
## Prepare the data set for the case study.
##

library(readxl)
library(dplyr)

CalcProductionOrder <- function(productionYear, seed = NULL){
  
  set.seed(seed)
  su_year <- sort(unique(productionYear))
  productionOrder <- vector(mode = "integer", length = length(productionYear))
  
  resample <- function(x, ...) x[sample.int(length(x), ...)]
  endIndex <- 0
  for(i in seq_along(su_year)){
    areCurrentYear <- su_year[i] == productionYear
    startIndex <- endIndex + 1
    endIndex <- endIndex + sum(areCurrentYear)
    indices <- startIndex:endIndex
    productionOrder[areCurrentYear] <- resample(indices)
  }
  
  return(productionOrder)  
}

rawData <- read_xlsx("Data\\ProductionAndReserveData.xlsx", 
                     sheet = "Resource Data", skip = 3,
                     col_names = FALSE)

# Elminate those rows for which the starting year (rawData[[11]]) is missing
# and the status (rawData[[3]]) is a developed prospect with reserves
rawData <- rawData[!is.na(rawData[[11]]) & rawData[[3]] != "DEVELOPED PROSPECT WITH RESERVES", ]

# The units for ore are metric tons, the units for gold are grams, and
# the units for grade are grams per metric ton.
mineData <- tibble(Name = rawData[[1]],
                   Longitude = rawData[[5]],
                   Latitude = rawData[[4]],
                   Status = rawData[[3]],
                   Classification = ifelse(Status == "PRODUCING MINE", "Current Producer", "Past Producer"),
                   StartingYear = rawData[[11]],
                   OreTons = rawData[[12]],
                   GoldGrams = rawData[[13]],
                   Grade = rawData[[14]]
)


mineData$productionOrder <- CalcProductionOrder(mineData$StartingYear, seed = 7)

save(mineData, file = "Data\\mineData.dat")

